==> fmtx-faker_0.2.tar.gz: fmtx-faker-0.2/src/fmtx-faker-obj.h <==
/*
 * fmtx-faker: Tricks fmtxd into thinking the transmitter is not disabled.
 *
 * Copyright (C) 2009 Faheem Pervez <trippin1@gmail.com>. All rights reserved.
 *
 *             DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
 *                   Version 2, December 2004
 *
 *	Copyright (C) 2004 Sam Hocevar
 *	14 rue de Plaisance, 75014 Paris, France
 *	Everyone is permitted to copy and distribute verbatim or modified
 *	copies of this license document, and changing it is allowed as long
 *	as the name is changed.
 *
 *           DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
 *  TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
 *
 * 	0. You just DO WHAT THE FUCK YOU WANT TO. 
 *
 * This program is free software. It comes without any warranty, to
 * the extent permitted by applicable law. You can redistribute it
 * and/or modify it under the terms of the Do What The Fuck You Want
 * To Public License, Version 2, as published by Sam Hocevar. See
 * http://sam.zoy.org/wtfpl/COPYING for more details.
 *
 */

/* fmtx-faker-obj.h */

#ifndef __FMTX_FAKER_OBJ_H__
#define __FMTX_FAKER_OBJ_H__

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <glib.h>
#include <glib-object.h>

G_BEGIN_DECLS

#define FMTX_FAKER_SERVICE_NAME CFG_FMTX_FAKER_SERVICE_NAME
#define FMTX_FAKER_OBJECT_PATH  CFG_FMTX_FAKER_OBJECT_PATH
#define FMTX_FAKER_INTERFACE    CFG_FMTX_FAKER_INTERFACE_NAME

#define FMTX_TYPE_FAKER (fmtx_faker_get_type ())

#define FMTX_FAKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
						FMTX_TYPE_FAKER, FMTXFaker))

#define FMTX_FAKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), \
						FMTX_TYPE_FAKER, FMTXFakerClass))

#define FMTX_IS_FAKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
						FMTX_TYPE_FAKER))

#define FMTX_IS_FAKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
						FMTX_TYPE_FAKER))

#define FMTX_FAKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), \
						FMTX_TYPE_FAKER, FMTXFakerClass))

typedef struct _FMTXFaker FMTXFaker;
typedef struct _FMTXFakerClass FMTXFakerClass;

struct _FMTXFaker
{
	GObject parent;
};

struct _FMTXFakerClass
{
	GObjectClass parent_class;
};

GType fmtx_faker_get_type (void);

FMTXFaker* fmtx_faker_new_with_fmtx_mode_property (const guchar value);

#if 0
FMTXFaker* fmtx_faker_new_with_properties (const gchar *first_property, ...);

FMTXFaker* fmtx_faker_new (void);
#endif

gboolean fmtx_faker_on_GetConfigValue_recieved (FMTXFaker *self, const gchar *string G_GNUC_UNUSED, GArray **out_array, GError **error);

G_END_DECLS

#endif /* __FMTX_FAKER_OBJ_H__ */

==> fmtx-faker_0.4.tar.gz: fmtx-faker-0.4/src/fmtx-faker-obj.h <==
/*
 * fmtx-faker: Tricks fmtxd into thinking the transmitter is not disabled.
 *
 * Copyright (C) 2009 Faheem Pervez <trippin1@gmail.com>. All rights reserved.
 *
 *             DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
 *                   Version 2, December 2004
 *
 *	Copyright (C) 2004 Sam Hocevar
 *	14 rue de Plaisance, 75014 Paris, France
 *	Everyone is permitted to copy and distribute verbatim or modified
 *	copies of this license document, and changing it is allowed as long
 *	as the name is changed.
 *
 *           DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE
 *  TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
 *
 * 	0. You just DO WHAT THE FUCK YOU WANT TO. 
 *
 * This program is free software. It comes without any warranty, to
 * the extent permitted by applicable law. You can redistribute it
 * and/or modify it under the terms of the Do What The Fuck You Want
 * To Public License, Version 2, as published by Sam Hocevar. See
 * http://sam.zoy.org/wtfpl/COPYING for more details.
 *
 */

/* fmtx-faker-obj.h */

#ifndef __FMTX_FAKER_OBJ_H__
#define __FMTX_FAKER_OBJ_H__

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#include <glib.h>
#include <glib-object.h>

G_BEGIN_DECLS

#define FMTX_FAKER_SERVICE_NAME CFG_FMTX_FAKER_SERVICE_NAME
#define FMTX_FAKER_OBJECT_PATH  CFG_FMTX_FAKER_OBJECT_PATH
#define FMTX_FAKER_INTERFACE    CFG_FMTX_FAKER_INTERFACE_NAME

#define FMTX_TYPE_FAKER (fmtx_faker_get_type ())

#define FMTX_FAKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
						FMTX_TYPE_FAKER, FMTXFaker))

#define FMTX_FAKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), \
						FMTX_TYPE_FAKER, FMTXFakerClass))

#define FMTX_IS_FAKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
						FMTX_TYPE_FAKER))

#define FMTX_IS_FAKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), \
						FMTX_TYPE_FAKER))

#define FMTX_FAKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), \
						FMTX_TYPE_FAKER, FMTXFakerClass))

typedef struct _FMTXFaker FMTXFaker;
typedef struct _FMTXFakerClass FMTXFakerClass;

struct _FMTXFaker
{
	GObject parent;
};

struct _FMTXFakerClass
{
	GObjectClass parent_class;
};

GType fmtx_faker_get_type (void);

FMTXFaker* fmtx_faker_new_with_fmtx_mode_property (const guchar value);

#if 0
FMTXFaker* fmtx_faker_new_with_properties (const gchar *first_property, ...);

FMTXFaker* fmtx_faker_new (void);
#endif

gboolean fmtx_faker_get_config_value (FMTXFaker *self, const gchar *string, GArray **out_array, GError **error);

G_END_DECLS

#endif /* __FMTX_FAKER_OBJ_H__ */
